==> haskell-html-entity-map-0.1.0.0-114-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-entity-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 html-entity-map
version:              0.1.0.0
visibility:           public
id:                   html-entity-map-0.1.0.0-41H9UnpwHhBIj0wkwezv4B
key:                  html-entity-map-0.1.0.0-41H9UnpwHhBIj0wkwezv4B
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/html-entity-map
synopsis:
    Map from HTML5 entity names to the corresponding Unicode text

description:
    Map from HTML5 entity names to the corresponding Unicode text.

category:             HTML
abi:                  1958cf460e9005f32f54d27f08dc1506
exposed:              True
exposed-modules:      Data.HTML.Entities
import-dirs:          /usr/lib/ghc-9.0.2/site-local/html-entity-map-0.1.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/html-entity-map-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-entity-map
hs-libraries:         HShtml-entity-map-0.1.0.0-41H9UnpwHhBIj0wkwezv4B
depends:
    base-4.15.1.0 text-1.2.5.0
    unordered-containers-0.2.19.1-AupS6pw9cGS61feF3nE08

haddock-interfaces:
    /usr/share/doc/haskell-html-entity-map/html/html-entity-map.haddock

haddock-html:         /usr/share/doc/haskell-html-entity-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-entity-map-0.1.0.0-132-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-entity-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 html-entity-map
version:              0.1.0.0
visibility:           public
id:                   html-entity-map-0.1.0.0-LX69ivXglvxBiO4pKLRQqq
key:                  html-entity-map-0.1.0.0-LX69ivXglvxBiO4pKLRQqq
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/html-entity-map
synopsis:
    Map from HTML5 entity names to the corresponding Unicode text

description:
    Map from HTML5 entity names to the corresponding Unicode text.

category:             HTML
abi:                  36f04da2f30937b24a49ceb9a9719d20
exposed:              True
exposed-modules:      Data.HTML.Entities
import-dirs:          /usr/lib/ghc-9.0.2/site-local/html-entity-map-0.1.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/html-entity-map-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-entity-map
hs-libraries:         HShtml-entity-map-0.1.0.0-LX69ivXglvxBiO4pKLRQqq
depends:
    base-4.15.1.0 text-1.2.5.0
    unordered-containers-0.2.19.1-KAeBL5aytSRB39idbhEXBI

haddock-interfaces:
    /usr/share/doc/haskell-html-entity-map/html/html-entity-map.haddock

haddock-html:         /usr/share/doc/haskell-html-entity-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
